==> nextcloud-13.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/updatenotification/l10n/ko.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version}을(를) 사용할 수 있습니다. 업데이트하는 방법에 대해서 알아보십시오.",
    "Could not start updater, please try the manual update" : "업데이트를 시작할 수 없습니다. 수동 업데이트를 시도하십시오.",
    "Open updater" : "업데이터 열기",
    "Download now" : "지금 다운로드",
    "Your version is up to date." : "최신 버전을 사용하고 있습니다.",
    "The update check is not yet finished. Please refresh the page." : "업데이트 확인이 아직 끝나지 않았습니다. 페이지를 새로 고치십시오.",
    "A non-default update server is in use to be checked for updates:" : "기본 업데이트 서버가 아닌 곳에서 업데이트를 확인하고 있음:",
    "Update channel:" : "업데이트 채널:",
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "항상 새로운 버전이나 실험 채널로 업그레이드할 수 있지만, 안정 채널로 다운그레이드할 수는 없습니다.",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "새 릴리스가 발표된 후 여기에 표시되기까지 시간이 소요됩니다. 새 버전은 단계적으로 적용되고 있으며 문제가 발생한 경우 버전을 건너뛸 수도 있습니다.",
    "Notify members of the following groups about available updates:" : "다음 그룹 구성원에게 업데이트 알림 전달:",
    "Only notification for app updates are available." : "앱 업데이트 알림만 사용할 수 있습니다.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "선택한 업데이트 채널은 서버 알림을 사용하지 않습니다.",
    "The selected update channel does not support updates of the server." : "선택한 업데이트 채널은 서버 업데이트를 지원하지 않습니다.",
    "Update notifications" : "업데이트 알림",
    "Channel updated" : "채널 업데이트됨",
    "The update server could not be reached since %d days to check for new updates." : "업데이트 서버에 %d일 동안 접근할 수 없어서 새 업데이트를 확인할 수 없습니다.",
    "Please check the Nextcloud and server log files for errors." : "Nextcloud 및 서버 로그에서 오류 정보를 확인하십시오.",
    "Update to %1$s is available." : "%1$s(으)로 업데이트할 수 있습니다.",
    "Update for %1$s to version %2$s is available." : "%1$s을(를) 버전 %2$s(으)로 업데이트할 수 있습니다.",
    "Update for {app} to version %s is available." : "{app}을(를) 버전 %s(으)로 업데이트할 수 있습니다.",
    "A new version is available: %s" : "새 버전을 사용할 수 있습니다: %s",
    "Checked on %s" : "%s에 확인함"
},
"nplurals=1; plural=0;");

==> nextcloud-13.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/updatenotification/l10n/ko.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version}을(를) 사용할 수 있습니다. 업데이트하는 방법에 대해서 알아보십시오.",
    "Update notifications" : "업데이트 알림",
    "Channel updated" : "채널 업데이트됨",
    "The update server could not be reached since %d days to check for new updates." : "업데이트 서버에 %d일 동안 접근할 수 없어서 새 업데이트를 확인할 수 없습니다.",
    "Please check the Nextcloud and server log files for errors." : "Nextcloud 및 서버 로그에서 오류 정보를 확인하십시오.",
    "Update to %1$s is available." : "%1$s(으)로 업데이트할 수 있습니다.",
    "Update for %1$s to version %2$s is available." : "%1$s을(를) 버전 %2$s(으)로 업데이트할 수 있습니다.",
    "Update for {app} to version %s is available." : "{app}을(를) 버전 %s(으)로 업데이트할 수 있습니다.",
    "Open updater" : "업데이터 열기",
    "The update check is not yet finished. Please refresh the page." : "업데이트 확인이 아직 끝나지 않았습니다. 페이지를 새로 고치십시오.",
    "A non-default update server is in use to be checked for updates:" : "기본 업데이트 서버가 아닌 곳에서 업데이트를 확인하고 있음:",
    "Update channel:" : "업데이트 채널:",
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "항상 새로운 버전이나 실험 채널로 업그레이드할 수 있지만, 안정 채널로 다운그레이드할 수는 없습니다.",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "새 릴리스가 발표된 후 여기에 표시되기까지 시간이 소요됩니다. 새 버전은 단계적으로 적용되고 있으며 문제가 발생한 경우 버전을 건너뛸 수도 있습니다.",
    "Notify members of the following groups about available updates:" : "다음 그룹 구성원에게 업데이트 알림 전달:",
    "Only notification for app updates are available." : "앱 업데이트 알림만 사용할 수 있습니다.",
    "The selected update channel does not support updates of the server." : "선택한 업데이트 채널은 서버 업데이트를 지원하지 않습니다.",
    "Could not start updater, please try the manual update" : "업데이트를 시작할 수 없습니다. 수동 업데이트를 시도하십시오.",
    "A new version is available: %s" : "새 버전을 사용할 수 있습니다: %s",
    "Download now" : "지금 다운로드",
    "Your version is up to date." : "최신 버전을 사용하고 있습니다.",
    "Checked on %s" : "%s에 확인함",
    "The selected update channel makes dedicated notifications for the server obsolete." : "선택한 업데이트 채널은 서버 알림을 사용하지 않습니다."
},
"nplurals=1; plural=0;");
